.. raw:: html

    <h1 align="center">Gstore</h1>
    <p align="center">
        <a href="https://gstore.readthedocs.io/en/stable/?badge=stable">
            <img src="https://readthedocs.org/projects/gstore/badge/?version=stable" alt="Documentation Status" />
        </a>
        <a href="https://github.com/sergeyklay/gstore/actions?workflow=CI">
            <img src="https://github.com/sergeyklay/gstore/workflows/CI/badge.svg?branch=main" alt="CI Status" />
        </a>
        <a href="https://coveralls.io/github/sergeyklay/gstore">
            <img src="https://coveralls.io/repos/github/sergeyklay/gstore/badge.svg" alt="Coverage Status" />
        </a>
    </p>

.. teaser-begin

Gstore is a simple tool to synchronize GitHub repositories of your organizations.

Its main goal is to help you make backups and sync your projects automatically
and easily.

.. teaser-end

.. -project-information-

Project Information
===================

Gstore is released under the `GNU General Public Licence version 3 <https://choosealicense.com/licenses/gpl-3.0/>`_,
its documentation lives at `Read the Docs <https://gstore.readthedocs.io/>`_,
the code on `GitHub <https://github.com/sergeyklay/gstore>`_,
and the latest release on `PyPI <https://pypi.org/project/gstore/>`_.
It’s rigorously tested on Python 3.8+.

If you'd like to contribute to Gstore you're most welcome!

.. -support-

Support
=======

Should you have any question, any remark, or if you find a bug, or if there is
something you can't do with the Gstore, please
`open an issue <https://github.com/sergeyklay/gstore/issues>`_.

.. -similar-projects-

Similar projects
================

There are some projects similar to Gstore you may be interested in:

* https://github.com/kennethreitz42/ghsync
* https://github.com/lgg/simple-git-mirror-sync
